@@ -6,7 +6,7 @@ use strict;
 
 use Exporter;
 
-$Locale::Currency::Format::VERSION = '1.28';
+$Locale::Currency::Format::VERSION = '1.32';
 
 @Locale::Currency::Format::ISA     = qw(Exporter);
 @Locale::Currency::Format::EXPORT  = qw(
@@ -463,7 +463,7 @@ MRO => ["Ouguiya",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 MTL => ["Maltese Lira",2,",",".","","\x{20A4}","&#x20A4;","Lm",1],
 MUR => ["Mauritius Rupee",0,",","","","\x{20A8}","&#x20A8;","Rs",1],
 MVR => ["Rufiyaa",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
-MWK => ["Kwacha",2,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
+MWK => ["Kwacha",2,",",".","",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 MXN => ["Mexican Peso",2,",","."," ","\x{0024}","&#x0024;","\$",1],
 MYR => ["Malaysian Ringgit",2,",",".","",$EMPTY,$EMPTY,"RM",1],
 MZN => ["Metical",2,".",","," ",$EMPTY,$EMPTY,"Mt",0],
@@ -513,7 +513,7 @@ TMM => ["Manat",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 TND => ["Tunisian Dinar",3,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 TOP => ["Pa'anga",2,",","."," ",$EMPTY,$EMPTY,"\$",1],
 TPE => ["Timor Escudo",$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY],
-TRL => ["Turkish Lira",0,",","","","\x{20A4}","&#x20A4;","TL",0],
+TRY => ["Turkish Lira",0,",","","","\x{20A4}","&#x20A4;","TL",0],
 TTD => ["Trinidad and Tobago Dollar",0,$EMPTY,$EMPTY,"","\x{0024}","&#x0024;",$EMPTY,$EMPTY],
 TWD => ["New Taiwan Dollar",0,$EMPTY,$EMPTY,"","\x{0024}","&#x0024;",$EMPTY,$EMPTY],
 TZS => ["Tanzanian Shilling",2,",","."," ",$EMPTY,$EMPTY,"TZs",0],
@@ -756,7 +756,7 @@ L<Locale::Currency>, L<Math::Currency>, L<Number::Format>, L<perluniintro>, L<pe
 
 =head1 BUGS
 
-If you find any inaccurate or missing information, please send your comments to L<tnguyen@cpan.org>. Your effort is certainly appreciated!
+Pull requests are greatly appreciated at https://github.com/tann/locale-currency-format
 
 =head1 CONTRIBUTOR(S)
 
